==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_entities/issuereturntransactionline_001/WorkOrderPartFailure.java <==

package net.datastream.schemas.mp_entities.issuereturntransactionline_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIONCODEID;
import net.datastream.schemas.mp_fields.CAUSECODEID;
import net.datastream.schemas.mp_fields.FAILURECODEID;
import net.datastream.schemas.mp_fields.PROBLEMCODEID;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTFAILUREQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTFAILUREDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROBLEMCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILURECODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIONCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAUSECODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILURENOTES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLOCATIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partfailurequantity",
    "partfailuredate",
    "problemcodeid",
    "failurecodeid",
    "actioncodeid",
    "causecodeid",
    "failurenotes",
    "partlocationcode"
})
@XmlRootElement(name = "WorkOrderPartFailure")
public class WorkOrderPartFailure {

    @XmlElement(name = "PARTFAILUREQUANTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY partfailurequantity;
    @XmlElement(name = "PARTFAILUREDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME partfailuredate;
    @XmlElement(name = "PROBLEMCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROBLEMCODEID problemcodeid;
    @XmlElement(name = "FAILURECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FAILURECODEID failurecodeid;
    @XmlElement(name = "ACTIONCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIONCODEID actioncodeid;
    @XmlElement(name = "CAUSECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CAUSECODEID causecodeid;
    @XmlElement(name = "FAILURENOTES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String failurenotes;
    @XmlElement(name = "PARTLOCATIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partlocationcode;

    /**
     * Obtient la valeur de la propriété partfailurequantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPARTFAILUREQUANTITY() {
        return partfailurequantity;
    }

    /**
     * Définit la valeur de la propriété partfailurequantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPARTFAILUREQUANTITY(QUANTITY value) {
        this.partfailurequantity = value;
    }

    /**
     * Obtient la valeur de la propriété partfailuredate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPARTFAILUREDATE() {
        return partfailuredate;
    }

    /**
     * Définit la valeur de la propriété partfailuredate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPARTFAILUREDATE(DATETIME value) {
        this.partfailuredate = value;
    }

    /**
     * Obtient la valeur de la propriété problemcodeid.
     * 
     * @return
     *     possible object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public PROBLEMCODEID getPROBLEMCODEID() {
        return problemcodeid;
    }

    /**
     * Définit la valeur de la propriété problemcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public void setPROBLEMCODEID(PROBLEMCODEID value) {
        this.problemcodeid = value;
    }

    /**
     * Obtient la valeur de la propriété failurecodeid.
     * 
     * @return
     *     possible object is
     *     {@link FAILURECODEID }
     *     
     */
    public FAILURECODEID getFAILURECODEID() {
        return failurecodeid;
    }

    /**
     * Définit la valeur de la propriété failurecodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link FAILURECODEID }
     *     
     */
    public void setFAILURECODEID(FAILURECODEID value) {
        this.failurecodeid = value;
    }

    /**
     * Obtient la valeur de la propriété actioncodeid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIONCODEID }
     *     
     */
    public ACTIONCODEID getACTIONCODEID() {
        return actioncodeid;
    }

    /**
     * Définit la valeur de la propriété actioncodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIONCODEID }
     *     
     */
    public void setACTIONCODEID(ACTIONCODEID value) {
        this.actioncodeid = value;
    }

    /**
     * Obtient la valeur de la propriété causecodeid.
     * 
     * @return
     *     possible object is
     *     {@link CAUSECODEID }
     *     
     */
    public CAUSECODEID getCAUSECODEID() {
        return causecodeid;
    }

    /**
     * Définit la valeur de la propriété causecodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link CAUSECODEID }
     *     
     */
    public void setCAUSECODEID(CAUSECODEID value) {
        this.causecodeid = value;
    }

    /**
     * Obtient la valeur de la propriété failurenotes.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFAILURENOTES() {
        return failurenotes;
    }

    /**
     * Définit la valeur de la propriété failurenotes.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFAILURENOTES(String value) {
        this.failurenotes = value;
    }

    /**
     * Obtient la valeur de la propriété partlocationcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTLOCATIONCODE() {
        return partlocationcode;
    }

    /**
     * Définit la valeur de la propriété partlocationcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTLOCATIONCODE(String value) {
        this.partlocationcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/issuereturntransactionline_001/WorkOrderPartFailure.java <==

package net.datastream.schemas.mp_entities.issuereturntransactionline_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIONCODEID;
import net.datastream.schemas.mp_fields.CAUSECODEID;
import net.datastream.schemas.mp_fields.FAILURECODEID;
import net.datastream.schemas.mp_fields.PROBLEMCODEID;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTFAILUREQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTFAILUREDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROBLEMCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILURECODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIONCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAUSECODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILURENOTES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLOCATIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partfailurequantity",
    "partfailuredate",
    "problemcodeid",
    "failurecodeid",
    "actioncodeid",
    "causecodeid",
    "failurenotes",
    "partlocationcode"
})
@XmlRootElement(name = "WorkOrderPartFailure")
public class WorkOrderPartFailure {

    @XmlElement(name = "PARTFAILUREQUANTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY partfailurequantity;
    @XmlElement(name = "PARTFAILUREDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME partfailuredate;
    @XmlElement(name = "PROBLEMCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROBLEMCODEID problemcodeid;
    @XmlElement(name = "FAILURECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FAILURECODEID failurecodeid;
    @XmlElement(name = "ACTIONCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIONCODEID actioncodeid;
    @XmlElement(name = "CAUSECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CAUSECODEID causecodeid;
    @XmlElement(name = "FAILURENOTES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String failurenotes;
    @XmlElement(name = "PARTLOCATIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partlocationcode;

    /**
     * Gets the value of the partfailurequantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPARTFAILUREQUANTITY() {
        return partfailurequantity;
    }

    /**
     * Sets the value of the partfailurequantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPARTFAILUREQUANTITY(QUANTITY value) {
        this.partfailurequantity = value;
    }

    /**
     * Gets the value of the partfailuredate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPARTFAILUREDATE() {
        return partfailuredate;
    }

    /**
     * Sets the value of the partfailuredate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPARTFAILUREDATE(DATETIME value) {
        this.partfailuredate = value;
    }

    /**
     * Gets the value of the problemcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public PROBLEMCODEID getPROBLEMCODEID() {
        return problemcodeid;
    }

    /**
     * Sets the value of the problemcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public void setPROBLEMCODEID(PROBLEMCODEID value) {
        this.problemcodeid = value;
    }

    /**
     * Gets the value of the failurecodeid property.
     * 
     * @return
     *     possible object is
     *     {@link FAILURECODEID }
     *     
     */
    public FAILURECODEID getFAILURECODEID() {
        return failurecodeid;
    }

    /**
     * Sets the value of the failurecodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FAILURECODEID }
     *     
     */
    public void setFAILURECODEID(FAILURECODEID value) {
        this.failurecodeid = value;
    }

    /**
     * Gets the value of the actioncodeid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIONCODEID }
     *     
     */
    public ACTIONCODEID getACTIONCODEID() {
        return actioncodeid;
    }

    /**
     * Sets the value of the actioncodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIONCODEID }
     *     
     */
    public void setACTIONCODEID(ACTIONCODEID value) {
        this.actioncodeid = value;
    }

    /**
     * Gets the value of the causecodeid property.
     * 
     * @return
     *     possible object is
     *     {@link CAUSECODEID }
     *     
     */
    public CAUSECODEID getCAUSECODEID() {
        return causecodeid;
    }

    /**
     * Sets the value of the causecodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAUSECODEID }
     *     
     */
    public void setCAUSECODEID(CAUSECODEID value) {
        this.causecodeid = value;
    }

    /**
     * Gets the value of the failurenotes property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFAILURENOTES() {
        return failurenotes;
    }

    /**
     * Sets the value of the failurenotes property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFAILURENOTES(String value) {
        this.failurenotes = value;
    }

    /**
     * Gets the value of the partlocationcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTLOCATIONCODE() {
        return partlocationcode;
    }

    /**
     * Sets the value of the partlocationcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTLOCATIONCODE(String value) {
        this.partlocationcode = value;
    }

}
